/*
 * Created on Oct 15, 2003
 */
package com.whitehill.wrapper.xep;

import java.io.*;
import org.xml.sax.InputSource;

public class XepWrapper implements XepWrapperMBean
{
    /** System property of the XEP root. */
    public static final String XEP_ROOT = "com.renderx.xep.ROOT";
    
    /** The xep root path. */
    private String root;
    
    /** The input xsl:fo file. */
    private String input;
    
    /** The output pdf file. */
    private String output;
    
    public void setRoot(String root) {
        this.root = root;
    }
    public void setInput(String input) {
        this.input = input;
    }
    public void setOutput(String output) {
        this.output = output;
    }
    
    public void start()
        throws Exception
    {
        File foFile = new File(input);
        File pdfFile = new File(output);
        
        if (!foFile.isFile()) {
            throw new IllegalStateException("File does not exist: "+foFile);
        }
        
        System.err.println("XEP Root: "+root);
        System.err.println("FO File:  "+foFile.getAbsolutePath());
        System.err.println("PDF File: "+pdfFile.getAbsolutePath());
        
        // Setup XEP properties
        java.util.Properties properties = System.getProperties();
        properties.setProperty(XEP_ROOT, root);
        System.setProperties(properties);
        
        // Initialize formatter driver class
        com.renderx.xep.Driver.init();
        
        InputStream in = new BufferedInputStream(
            new FileInputStream(foFile));
        OutputStream out = new BufferedOutputStream(
            new FileOutputStream(pdfFile));
        
        try
        {
            // Initialize PDF generator class
            com.renderx.xep.gen.backends.H4PDF generator = 
                new com.renderx.xep.gen.backends.H4PDF();
            generator.setOutFile(out);
            
            // Run XEP, suppressing diagnostic output
            com.renderx.xep.Driver.render(new InputSource(in), generator);
        }
        finally {
            in.close();
        }
    }
    
    public static void main(String[] args)
    {
        if (args.length < 3)
        {
            System.err.println("Command line options: <xep-root> <fo-file> <pdf-file>");
            System.exit(-1);
        }
        
        XepWrapper wrapper = new XepWrapper();
        wrapper.setRoot(args[0]);
        wrapper.setInput(args[1]);
        wrapper.setOutput(args[2]);
        
        try {
            wrapper.start();
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }
}
